require "spec_helper"
require "simple_ca/sign_csr"

describe SimpleCA::SignCSR do
  describe "#call" do
    let(:key) { OpenSSL::PKey::RSA.new(File.read "spec/support/fixtures/root.key") }
    let(:root) { OpenSSL::X509::Certificate.new(File.read "spec/support/fixtures/root.crt") }
    subject { described_class.new(root, key) }

    context "when the CSR is valid" do
      let(:csr) { OpenSSL::X509::Request.new(File.read "spec/support/fixtures/test.csr") }

      it "returns a certificate signed by the key" do
        expect(subject.call csr).to be_a_certificate_signed_by(key)
      end

      it "sets the issuer to the root certificate" do
        expect(subject.call(csr).issuer).to eq root.subject
      end
    end
  end
end
